@@ -17,9 +17,9 @@ def monad(bfn: Any) -> Any:
         :rtype: Any
         """
         try:
-            if not fn:
+            if fn is None:
                 return bfn
-            elif not bfn:
+            elif bfn is None:
                 return monad(None)
             else:
                 return monad(fn(bfn))
